==> spring-security-starter-1.2.3.14-Release-sources.jar: com/bizunited/platform/rbac/security/starter/service/security/SimpleAuthenticationProvider.java <==
package com.bizunited.platform.rbac.security.starter.service.security;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.AuthenticationCredentialsNotFoundException;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Component;

import com.bizunited.platform.rbac.security.starter.service.security.authenticate.AuthenticationDecision;
import com.bizunited.platform.rbac.server.service.RoleService;
import com.bizunited.platform.rbac.server.service.UserService;
import com.bizunited.platform.rbac.server.vo.RoleVo;
import com.bizunited.platform.rbac.server.vo.UserVo;

/**
 * 重写的用于多种鉴权鉴权场景下，确定用户是否鉴权成功的处理器</br>
 * 其核心原理为：用户信息查询服务（权限模块使用），用来查询指定的用户基本信息（但是包括角色信息）
 * @author yinwenjie
 */
@Component
public class SimpleAuthenticationProvider implements AuthenticationProvider {
  /**
   * 日志
   */
  private static final Logger LOGGER = LoggerFactory.getLogger(SimpleAuthenticationProvider.class);
  private static final String ERROR_TYPE = "目前用户鉴权模式支持6中方式：1、典型的用户名+密码方式；2、典型的用户名 + 密码 + 校验码方式；3、用户名 + 短信验证码 + 校验码方式； 4、手机号 + 密码方式；5、手机号 + 短信验证码；6、手机号 + 短信验证码 + 校验码方式；7、业务系统自定的其它登录方式";
  private static final String ERROR_USER = "未发现指定的用户信息或其数据存储编号，也可能是因为指定的鉴权方式暂未实现";
  private static final String ERROR_ROLE = "未发现指定的用户带有任务角色信息，请检查用户权限设定";
  /**
   * 默认的用户密码
   */
  private static final String DEFAULT_SE = "12345678";
  @Autowired
  private RoleService roleService;
  @Autowired
  private UserService userService;
  /**
   * 鉴权方式
   */
  @Autowired
  private List<AuthenticationDecision> authenticationDecisions;
  
  @Override
  public Authentication authenticate(Authentication authentication) throws AuthenticationException {
    LoginDetails loginDetails = (LoginDetails) authentication.getDetails();//拿到表单的其他信息
    LOGGER.debug("当前有用户正在进行经典登录鉴权 =  " + loginDetails.toString());
    Integer type = loginDetails.getType();
    Validate.isTrue(type > 0 && type <= 7 , ERROR_TYPE);
    
    /*
     * node:处理过程为：
     * 1、首先根据type，确定应该使用的鉴权方式，注意：如果这一步抛出异常或者返回了null，说明鉴权失败。
     * 2、接着根据返回的userid，得到这个用户的角色信息，并组装最后的token信息
     * .角色的来源有几部分
     *   a、当前用户直接绑定的角色
     *   b、当前用户所属的一个或者多个用户组绑定的角色
     *   c、当前用户所属组织机构、组织机构的各父级组织结构所绑定的角色
     * .注意：以上步骤中，如果找到了ADMIN这样存在于ignoreMethodCheckRoles配置中的角色时，就不需要再继续找了。
     * .因为一旦有了这个角色，就不再受角色-功能的绑定限制了，任何功能都可以访问
     * 3、如果当前用户没有密码，则必须为当前用户构建初始化密码（123456），因为鉴权成功后通过
     * CustomUserSecurityDetailsService读取用户详细信息时，需要这个密码
     * */
    
    // 1、==========
    UserVo currentUser = null;
    try {
      for (AuthenticationDecision authenticationDecision : authenticationDecisions) {
        Integer currentCode = authenticationDecision.type().getCode();
        if(currentCode == type) {
          currentUser = authenticationDecision.authenticate(loginDetails);
          break;
        }
      }
    } catch(RuntimeException e) {
      throw new AuthenticationCredentialsNotFoundException(e.getMessage() , e);
    }
    if(currentUser == null || StringUtils.isBlank(currentUser.getId())) {
      throw new UsernameNotFoundException(ERROR_USER);
    }
    
    // 2、=========
    // 查询用户角色信息
    List<RoleVo> roles = null;
    roles = this.roleService.findAllByUserId(currentUser.getId());
    if(roles == null || roles.isEmpty()) {
      throw new BadCredentialsException(ERROR_ROLE);
    }
    List<SimpleGrantedAuthority> authorities = new ArrayList<>();
    for (RoleVo role : roles) {
      SimpleGrantedAuthority authoritie = new SimpleGrantedAuthority(StringUtils.upperCase(role.getRoleName()));
      authorities.add(authoritie);
    }
    
    // 3、========
    String password = currentUser.getPassword();
    if(StringUtils.isBlank(password)) {
      currentUser = this.userService.updatePassword(currentUser.getId(), DEFAULT_SE);
    }
    
    // 构建返回的用户登录成功的token
    return new UsernamePasswordAuthenticationToken(currentUser.getAccount(), currentUser.getPassword(), authorities);
  }

  @Override
  public boolean supports(Class<?> authentication) {
    // TODO 正常来说，这里应该根据不同的典型鉴权场景确认该provider是否可用
    return true;
  }

}

==> spring-security-starter-2.0.1.1-Release-sources.jar: com/bizunited/platform/rbac/security/starter/service/security/SimpleAuthenticationProvider.java <==
package com.bizunited.platform.rbac.security.starter.service.security;

import com.bizunited.platform.rbac.security.starter.service.security.authenticate.AuthenticationDecision;
import com.bizunited.platform.rbac.server.service.RoleService;
import com.bizunited.platform.rbac.server.service.UserService;
import com.bizunited.platform.rbac.server.vo.RoleVo;
import com.bizunited.platform.rbac.server.vo.UserVo;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.AuthenticationCredentialsNotFoundException;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * 重写的用于多种鉴权鉴权场景下，确定用户是否鉴权成功的处理器</br>
 * 其核心原理为：用户信息查询服务（权限模块使用），用来查询指定的用户基本信息（但是包括角色信息）
 * @author yinwenjie
 */
@Component
public class SimpleAuthenticationProvider implements AuthenticationProvider {
  /**
   * 日志
   */
  private static final Logger LOGGER = LoggerFactory.getLogger(SimpleAuthenticationProvider.class);
  private static final String ERROR_TYPE = "目前用户鉴权模式支持6中方式：1、典型的用户名+密码方式；2、典型的用户名 + 密码 + 校验码方式；3、用户名 + 短信验证码 + 校验码方式； 4、手机号 + 密码方式；5、手机号 + 短信验证码；6、手机号 + 短信验证码 + 校验码方式；7、业务系统自定的其它登录方式";
  private static final String ERROR_USER = "未发现指定的用户信息或其数据存储编号，也可能是因为指定的鉴权方式暂未实现";
  private static final String ERROR_ROLE = "未发现指定的用户带有任务角色信息，请检查用户权限设定";
  /**
   * 默认的用户密码
   */
  private static final String DEFAULT_SE = "12345678";
  @Autowired
  private RoleService roleService;
  @Autowired
  private UserService userService;
  /**
   * 鉴权方式
   */
  @Autowired
  private List<AuthenticationDecision> authenticationDecisions;
  
  @Override
  public Authentication authenticate(Authentication authentication) throws AuthenticationException {
    //拿到表单的其他信息
    LoginDetails loginDetails = (LoginDetails) authentication.getDetails();
    LOGGER.debug("当前有用户正在进行经典登录鉴权 =  " + loginDetails.toString());
    Integer type = loginDetails.getType();
    Validate.isTrue(type > 0 && type <= 7 , ERROR_TYPE);
    
    /*
     * node:处理过程为：
     * 1、首先根据type，确定应该使用的鉴权方式，注意：如果这一步抛出异常或者返回了null，说明鉴权失败。
     * 2、接着根据返回的userid，得到这个用户的角色信息，并组装最后的token信息
     * .角色的来源有几部分
     *   a、当前用户直接绑定的角色
     *   b、当前用户所属的一个或者多个用户组绑定的角色
     *   c、当前用户所属组织机构、组织机构的各父级组织结构所绑定的角色
     * .注意：以上步骤中，如果找到了ADMIN这样存在于ignoreMethodCheckRoles配置中的角色时，就不需要再继续找了。
     * .因为一旦有了这个角色，就不再受角色-功能的绑定限制了，任何功能都可以访问
     * 3、如果当前用户没有密码，则必须为当前用户构建初始化密码（123456），因为鉴权成功后通过
     * CustomUserSecurityDetailsService读取用户详细信息时，需要这个密码
     * */
    
    // 1、==========
    UserVo currentUser = null;
    try {
      for (AuthenticationDecision authenticationDecision : authenticationDecisions) {
        Integer currentCode = authenticationDecision.type().getCode();
        if(currentCode.equals(type)) {
          currentUser = authenticationDecision.authenticate(loginDetails);
          break;
        }
      }
    } catch(RuntimeException e) {
      throw new AuthenticationCredentialsNotFoundException(e.getMessage() , e);
    }
    if(currentUser == null || StringUtils.isBlank(currentUser.getId())) {
      throw new UsernameNotFoundException(ERROR_USER);
    }
    
    // 2、=========
    // 查询用户角色信息
    List<RoleVo> roles = null;
    roles = this.roleService.findAllByUserId(currentUser.getId());
    if(roles == null || roles.isEmpty()) {
      throw new BadCredentialsException(ERROR_ROLE);
    }
    List<SimpleGrantedAuthority> authorities = new ArrayList<>();
    for (RoleVo role : roles) {
      SimpleGrantedAuthority authoritie = new SimpleGrantedAuthority(StringUtils.upperCase(role.getRoleName()));
      authorities.add(authoritie);
    }
    
    // 3、========
    String password = currentUser.getPassword();
    if(StringUtils.isBlank(password)) {
      currentUser = this.userService.updatePassword(currentUser.getId(), DEFAULT_SE);
    }
    
    // 构建返回的用户登录成功的token
    return new UsernamePasswordAuthenticationToken(currentUser.getAccount(), currentUser.getPassword(), authorities);
  }

  @Override
  public boolean supports(Class<?> authentication) {
    // TODO 正常来说，这里应该根据不同的典型鉴权场景确认该provider是否可用
    return true;
  }

}
